@@ -85,13 +85,14 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
     only official releases with latest and previous version support.
     """
 
-    def _get_repo_from_defintion(
+    def _get_repo_from_definition(
         commit_type: CommitConvention,
         hvcs_client_name: str = "github",
         hvcs_domain: str = EXAMPLE_HVCS_DOMAIN,
         tag_format_str: str | None = None,
         extra_configs: dict[str, TomlSerializableTypes] | None = None,
-        mask_initial_release: bool = False,
+        mask_initial_release: bool = True,
+        ignore_merge_commits: bool = True,
     ) -> Sequence[RepoActions]:
         stable_now_datetime = stable_now_date()
         commit_timestamp_gen = (
@@ -99,7 +100,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
             for i in count(step=1)
         )
 
-        changelog_file_definitons: Sequence[RepoActionWriteChangelogsDestFile] = [
+        changelog_file_definitions: Sequence[RepoActionWriteChangelogsDestFile] = [
             {
                 "path": changelog_md_file,
                 "format": ChangelogOutputFormat.MARKDOWN,
@@ -149,7 +150,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
-                                    "angular": INITIAL_COMMIT_MESSAGE,
+                                    "conventional": INITIAL_COMMIT_MESSAGE,
                                     "emoji": INITIAL_COMMIT_MESSAGE,
                                     "scipy": INITIAL_COMMIT_MESSAGE,
                                     "datetime": next(commit_timestamp_gen),
@@ -158,7 +159,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                     ),
                                 },
                                 {
-                                    "angular": "feat: add new feature",
+                                    "conventional": "feat: add new feature",
                                     "emoji": ":sparkles: add new feature",
                                     "scipy": "ENH: add new feature",
                                     "datetime": next(commit_timestamp_gen),
@@ -179,7 +180,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -198,7 +199,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
-                                    "angular": "fix: correct some text",
+                                    "conventional": "fix: correct some text",
                                     "emoji": ":bug: correct some text",
                                     "scipy": "MAINT: correct some text",
                                     "datetime": next(commit_timestamp_gen),
@@ -219,7 +220,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -251,7 +252,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
-                                    "angular": str.join(
+                                    "conventional": str.join(
                                         "\n\n",
                                         [
                                             "feat: add revolutionary feature",
@@ -269,7 +270,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                         "\n\n",
                                         [
                                             "API: add revolutionary feature",
-                                            "BREAKING CHANGE: this is a breaking change",
+                                            "This is a breaking change",
                                         ],
                                     ),
                                     "datetime": next(commit_timestamp_gen),
@@ -290,7 +291,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -314,9 +315,9 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
-                                    "angular": "fix: correct critical bug",
-                                    "emoji": ":bug: correct critical bug",
-                                    "scipy": "MAINT: correct critical bug",
+                                    "conventional": "fix: correct critical bug\n\nResolves: #123\n",
+                                    "emoji": ":bug: correct critical bug\n\nResolves: #123\n",
+                                    "scipy": "MAINT: correct critical bug\n\nResolves: #123\n",
                                     "datetime": next(commit_timestamp_gen),
                                     "include_in_changelog": True,
                                 },
@@ -336,7 +337,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                 "details": {
                                     "new_version": new_version,
                                     "max_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -355,7 +356,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
-                                    "angular": "fix: resolve critical bug",
+                                    "conventional": "fix: resolve critical bug",
                                     "emoji": ":bug: resolve critical bug",
                                     "scipy": "MAINT: resolve critical bug",
                                     "datetime": next(commit_timestamp_gen),
@@ -377,7 +378,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                 "details": {
                                     "new_version": new_version,
                                     "max_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -396,7 +397,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                 #         "commits": convert_commit_specs_to_commit_defs(
                 #             [
                 #                 {
-                #                     "angular": "docs: update documentation regarding critical bug",
+                #                     "conventional": "docs: update documentation regarding critical bug",
                 #                     "emoji": ":books: update documentation regarding critical bug",
                 #                     "scipy": "DOC: update documentation regarding critical bug",
                 #                     "datetime": next(commit_timestamp_gen),
@@ -418,7 +419,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                 "details": {
                                     "new_version": new_version,
                                     "max_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
                                 },
                             },
                         ],
@@ -441,7 +442,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
 
         return repo_construction_steps
 
-    return _get_repo_from_defintion
+    return _get_repo_from_definition
 
 
 @pytest.fixture(scope="session")
@@ -484,14 +485,14 @@ def build_trunk_only_repo_w_dual_version_spt_w_prereleases(
 
 
 @pytest.fixture
-def repo_w_trunk_only_dual_version_spt_w_prereleases_angular_commits(
+def repo_w_trunk_only_dual_version_spt_w_prereleases_conventional_commits(
     build_trunk_only_repo_w_dual_version_spt_w_prereleases: BuildSpecificRepoFn,
     example_project_git_repo: ExProjectGitRepoFn,
     example_project_dir: ExProjectDir,
     change_to_ex_proj_dir: None,
 ) -> BuiltRepoResult:
     repo_name = (
-        repo_w_trunk_only_dual_version_spt_w_prereleases_angular_commits.__name__
+        repo_w_trunk_only_dual_version_spt_w_prereleases_conventional_commits.__name__
     )
     commit_type: CommitConvention = repo_name.split("_")[-2]  # type: ignore[assignment]
 
